"use strict";

this.name        = "New-GalDrive-Programmer";
this.author      = "Wildeblood";
this.copyright   = "(C) 2011, 2012, 2024, Wildeblood";
this.description = "A limited selection of programmed destinations for the Galactic Hyper-drive.";
this.version     = "1.2";

this.destinations = new Array(8);

/* ====================================================================================
			DESTINATIONS ARRAY

	Add any interesting destinations found to the appropriate sub-array.
	This assumes Oolite's default galaxy seeds, copied from Elite. (Boring!)
======================================================================================= */

this.destinations[0] = new Array(
	["Lave (Old Worlds)",[8, 34.6, 0]],
	["Sori (Ascension)",[100.4, 50.4, 0]],
	["Tianve (Pulsar Worlds)",[90.8, 0, 0]],
	["Usralaat",[73.6, 35.8, 0]],
	["Vetitice (Galcentre G1)",[42, 30.4, 0]]
);

this.destinations[1] = new Array(
	["Ramaan",[100.4, 50.2, 0]],
	["Reenus",[2.8, 24.8, 0]],
	["Riardi",[1.6, 46.2, 0]],
	["Sosole",[70.8, 47.6, 0]]
);

this.destinations[2] = new Array(
	["Ditere (Prodigal Suns)",[27.2, 2, 0]],
	["Enata",[68.4, 35.8, 0]],
	["Ingece",[8.4, 25.8, 0]],
	["Oninriar",[97.2, 11.6, 0]]
);

this.destinations[3] = new Array(
	["Anerined",[89.6, 17, 0]],
	["Ensoza",[42, 40.6, 0]],
	["Esarqure",[53.6, 24.4, 0]],
	["Laisxela",[6.4, 17.4, 0]]
);

this.destinations[4] = new Array(
	["Atredi (Tetiri Conclave)",[4.8, 48, 0]],
	["Engeatso (Galcentre G5)",[62.4, 29.6, 0]],
	["Inmaarxe",[7.6, 21.4, 0]],
	["Qulecele",[93.2, 18.6, 0]]
);

this.destinations[5] = new Array(
	["Diraonle (Isaanus Syndicate)",[100.8, 46.6, 0]],
	["Estebiin (Lost Worlds)",[89.2, 48.6, 0]],
	["Qutius (Lost Worlds)",[85.2, 39.8, 0]],
	["Ririso (Rabian Spur)",[68, 4.4, 0]]
);

this.destinations[6] = new Array(
	["Articeso (Rift Worlds)",[1.2, 27.4, 0]],
	["Esvesoso",[41.2, 26.6, 0]],
	["Isdilaon",[68, 26.6, 0]],
	["Xeonar (Rift Worlds)",[15.6, 36.2, 0]]
);

this.destinations[7] = new Array(
	["Maarabi (Galcentre G8)",[61.2, 20.2, 0]],
	["Maatxeri",[15.2, 25.4, 0]],
	["Oresrati (Lost Worlds)",[6.4, 51, 0]],
	["Teescear (Far Arm)",[102, 40.8, 0]]
);

/* ====================================================================================
			STEPS THROUGH THE CO-ORDINATE ARRAYS WHEN ACTIVATED
======================================================================================= */

    this.activationCounter = -1;

    this.activated = function () {
        "use strict";
        player.consoleMessage("Galactic Hyperdrive", 3);
        var nextGalaxy = galaxyNumber + 1;
        if (galaxyNumber === 7) {
            nextGalaxy = 0;
        }
        this.activationCounter++;
        if (this.activationCounter === this.destinations[nextGalaxy].length) {
            player.ship.galacticHyperspaceBehaviour = "BEHAVIOUR_STANDARD";
            player.consoleMessage("Automatic navigation to GalCop recommended destination.", 3);
            return;
        }
        if (this.activationCounter > this.destinations[nextGalaxy].length) {
            this.activationCounter = 0;
        }
        player.ship.galacticHyperspaceBehaviour = "BEHAVIOUR_FIXED_COORDINATES";
        this.destinationName = this.destinations[nextGalaxy][this.activationCounter][0];
        player.ship.galacticHyperspaceFixedCoordsInLY = Vector3D(this.destinations[nextGalaxy][this.activationCounter][1]);
        player.commsMessage("Co-ordinates: " + player.ship.galacticHyperspaceFixedCoordsInLY, 6);
        player.commsMessage("Destination: " + this.destinationName, 6);
    }

/* ====================================================================================
			EVENT HANDLERS
======================================================================================= */

    this.startUpComplete = function () {
        "use strict";
        if (player.ship.equipmentStatus("EQ_GAL_DRIVE") === "EQUIPMENT_OK") {
            this._applyInterface();
        }
        delete this.startUpComplete;
    }

    this.playerBoughtEquipment = function (equipment) {
        "use strict";
        if (equipment === "EQ_GAL_DRIVE") {
            this._applyInterface();
        }
    }

    this.shipDockedWithStation = function () {
        "use strict";
        if (player.ship.equipmentStatus("EQ_GAL_DRIVE") === "EQUIPMENT_OK") {
            this._applyInterface();
        }
    }

    this.shipWillLaunchFromStation = function () {
        "use strict";
        player.ship.dockedStation.setInterface("new_galdrive", null);
    }

/* ====================================================================================
			STATION INTERFACE

    TO-DO: Show this.destinationName on the interface summary.
======================================================================================= */

    this._applyInterface = function () {
        "use strict";
        if (player.ship.dockedStation) {
            player.ship.dockedStation.setInterface("new_galdrive", {
                title: "Galactic™ hyperdrive",
                category: expandDescription("[interfaces-category-ship-systems]"),
                summary: "Activate this to reset the destination programmed into your ultra-long-range Galactic™ hyperdrive.",
                callback: this.activated.bind(this)
            });
        }
    }

/* ====================================================================================
			THE END
======================================================================================= */
